@@ -7,7 +7,7 @@ __author__ = "P J Kershaw"
 __date__ = "15/02/10"
 __copyright__ = "(C) 2010 Science and Technology Facilities Council"
 __contact__ = "Philip.Kershaw@stfc.ac.uk"
-__revision__ = "$Id: queryinterface.py 7634 2010-10-20 20:23:29Z pjkersha $"
+__revision__ = "$Id: queryinterface.py 7694 2010-11-03 08:53:22Z pjkersha $"
 __license__ = "http://www.apache.org/licenses/LICENSE-2.0"
 import logging
 log = logging.getLogger(__name__)
@@ -67,6 +67,7 @@ class SOAPQueryInterfaceMiddleware(SOAPMiddleware):
     SAML_VERSION_OPTNAME = 'samlVersion'
     ISSUER_NAME_OPTNAME = 'issuerName'
     ISSUER_FORMAT_OPTNAME = 'issuerFormat'
+    CLOCK_SKEW_TOLERANCE_OPTNAME = 'clockSkewTolerance'
     
     CONFIG_FILE_OPTNAMES = (
         PATH_OPTNAME,
@@ -78,7 +79,8 @@ class SOAPQueryInterfaceMiddleware(SOAPMiddleware):
         DESERIALISE_OPTNAME,
         SAML_VERSION_OPTNAME,
         ISSUER_NAME_OPTNAME,
-        ISSUER_FORMAT_OPTNAME
+        ISSUER_FORMAT_OPTNAME,
+        CLOCK_SKEW_TOLERANCE_OPTNAME
     )
     
     def __init__(self, app):
@@ -92,8 +94,7 @@ class SOAPQueryInterfaceMiddleware(SOAPMiddleware):
         # Set defaults
         cls = SOAPQueryInterfaceMiddleware
         self.__queryInterfaceKeyName = cls.DEFAULT_QUERY_INTERFACE_KEYNAME
-        self.__mountPath = None
-        self.mountPath = '/'
+        self.__mountPath = '/'
         self.__requestEnvelopeClass = None
         self.__responseEnvelopeClass = None
         self.__serialise = None
@@ -496,20 +497,17 @@ class SOAPQueryInterfaceMiddleware(SOAPMiddleware):
             return
         
         if query.version < self.samlVersion:
-            msg = ("Query SAML version %r is lower than the supported "
-                   "value %r"
-                   % (query.version, self.samlVersion))
+            log.debug("Query SAML version %r is lower than the supported "
+                      "value %r", query.version, self.samlVersion)
             response.status.statusCode.value = \
                                         StatusCode.REQUEST_VERSION_TOO_LOW_URI
-            return
         
         elif query.version > self.samlVersion:
-            msg = ("Query SAML version %r is higher than the supported "
-                   "value %r"
-                   % (query.version, self.samlVersion))
+            log.debug("Query SAML version %r is higher than the supported "
+                      "value %r", query.version, self.samlVersion)
             response.status.statusCode.value = \
                                         StatusCode.REQUEST_VERSION_TOO_HIGH_URI
-            return            
+            
         
     def _initResponse(self):
         """Create a SAML Response object with basic settings if any have been
