@@ -7,7 +7,7 @@ __date__ = "21/07/09"
 __copyright__ = "(C) 2009 Science and Technology Facilities Council"
 __license__ = "http://www.apache.org/licenses/LICENSE-2.0"
 __contact__ = "Philip.Kershaw@stfc.ac.uk"
-__revision__ = '$Id: test_queryresponseinterface.py 7526 2010-09-27 12:08:12Z pjkersha $'
+__revision__ = '$Id: test_queryresponseinterface.py 7694 2010-11-03 08:53:22Z pjkersha $'
 import logging
 logging.basicConfig(level=logging.DEBUG)
 log = logging.getLogger(__name__)
@@ -300,8 +300,7 @@ class SamlAttributeQueryTestCase(unittest.TestCase):
             'notOnOrAfter': SAMLDateTime.toString(utcNow + timedelta(
                                                             seconds=60*60*8))
         }
-        responseStr = self.__class__.RESPONSE % \
-                                                                        respDict
+        responseStr = self.__class__.RESPONSE % respDict
         response = self._parseResponse(responseStr)
         self.assert_(response)
 
@@ -316,8 +315,7 @@ class SamlAttributeQueryTestCase(unittest.TestCase):
             'notOnOrAfter': SAMLDateTime.toString(issueInstant + timedelta(
                                                             seconds=60*60*8))
         }
-        responseStr = self.__class__.RESPONSE % \
-                                                                    respDict
+        responseStr = self.__class__.RESPONSE % respDict
         response = self._parseResponse(responseStr)
         binding = SubjectQuerySOAPBinding()
         try:
@@ -336,8 +334,7 @@ class SamlAttributeQueryTestCase(unittest.TestCase):
             'notOnOrAfter': SAMLDateTime.toString(utcNow + timedelta(
                                                             seconds=60*60*8))
         }
-        responseStr = self.__class__.RESPONSE % \
-                                                                    respDict
+        responseStr = self.__class__.RESPONSE % respDict
         response = self._parseResponse(responseStr)
         binding = SubjectQuerySOAPBinding()
         try:
@@ -355,8 +352,7 @@ class SamlAttributeQueryTestCase(unittest.TestCase):
             'notOnOrAfter': SAMLDateTime.toString(utcNow + timedelta(
                                                             seconds=60*60*8))
         }
-        responseStr = self.__class__.RESPONSE % \
-                                                                    respDict
+        responseStr = self.__class__.RESPONSE % respDict
         response = self._parseResponse(responseStr)
         binding = SubjectQuerySOAPBinding()
         try:
@@ -375,8 +371,7 @@ class SamlAttributeQueryTestCase(unittest.TestCase):
             'notOnOrAfter': SAMLDateTime.toString(utcNow + timedelta(
                                                             seconds=60*60*8))
         }
-        responseStr = self.__class__.RESPONSE % \
-                                                                    respDict
+        responseStr = self.__class__.RESPONSE % respDict
         response = self._parseResponse(responseStr)
         binding = SubjectQuerySOAPBinding()
         try:
@@ -395,8 +390,7 @@ class SamlAttributeQueryTestCase(unittest.TestCase):
             'notOnOrAfter': SAMLDateTime.toString(utcNow + timedelta(
                                                             seconds=60*60*8))
         }
-        responseStr = self.__class__.RESPONSE % \
-                                                                    respDict
+        responseStr = self.__class__.RESPONSE % respDict
         response = self._parseResponse(responseStr)
         binding = SubjectQuerySOAPBinding()
         
