@@ -26,7 +26,7 @@ __copyright__ = "(C) 2009 Science and Technology Facilities Council"
 __contact__ = "Philip.Kershaw@stfc.ac.uk"
 __license__ = "http://www.apache.org/licenses/LICENSE-2.0"
 __contact__ = "Philip.Kershaw@stfc.ac.uk"
-__revision__ = "$Id: etree.py 7259 2010-08-02 12:26:32Z pjkersha $"
+__revision__ = "$Id: etree.py 7673 2010-11-01 11:05:50Z pjkersha $"
 import logging
 log = logging.getLogger(__name__)
 import re
@@ -940,7 +940,7 @@ class AttributeValueElementTreeFactory(object):
     toSAMLTypeMap = [xsstringMatch]
     xsstringMatch = staticmethod(toSAMLTypeMap[0])
    
-    def __init__(self, customToXMLTypeMap={}, customToSAMLTypeMap=[]): 
+    def __init__(self, customToXMLTypeMap=None, customToSAMLTypeMap=None): 
         """Set-up a SAML class to ElementTree mapping
         
         @type customToXMLTypeMap: dict
@@ -953,6 +953,12 @@ class AttributeValueElementTreeFactory(object):
         representations.  As with customToXMLTypeMap, this appends to
         to the respective self.__toSAMLTypeMap
         """
+        if customToXMLTypeMap is None:
+            customToXMLTypeMap = {}
+            
+        if customToSAMLTypeMap is None:
+            customToSAMLTypeMap = []
+            
         self.__toXMLTypeMap = AttributeValueElementTreeFactory.toXMLTypeMap
         if not isinstance(customToXMLTypeMap, dict):
             raise TypeError('Expecting dict type for "customToXMLTypeMap"')
